# Copyright (c) 2012 Spotify AB
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

import os

try:
    from setuptools import setup
except:
    from distutils.core import setup

try:
    # Convert the Markdown Readme into raw text so that it looks good in PyPi.
    # Simple workaround because PyPi does't support Markdown.
    # https://pypi.python.org/pypi/luigi
    import textwrap

    long_description = ['NOTE: For the latest code, please go to https://github.com/spotify/luigi',
                        'To read the full documentation, please go to http://luigi.readthedocs.org']

    for line in open('README.rst'):
        # Strip stuff
        if line.startswith('.') or line.startswith(' '):
            continue
        line = line.replace('`', '').replace('__', '_').replace('>_', '>')

        # Wrap lines
        for line in textwrap.wrap(line, 120, drop_whitespace=False):
            long_description.append(line)

    long_description = '\n'.join(long_description)

except Exception, e:
    import traceback
    traceback.print_exc()
    long_description = ''

# long_description = ''.join(open('README.rst').readlines())

luigi_package_data = [os.path.join(dirpath.replace("luigi/", ""), ext)
                      for (dirpath, dirnames, filenames) in os.walk("luigi/static")
                      for ext in ["*.html", "*.js", "*.css", "*.png"]]

long_description = ['Note: For the latest source, discussion, etc, please visit the `Github repository <https://github.com/spotify/luigi>`_\n\n']
for line in open('README.rst'):
    long_description.append(line)
long_description = ''.join(long_description)

setup(
    name='luigi',
    version='1.0.26',
    description='Workflow mgmgt + task scheduling + dependency resolution',
    long_description=long_description,
    author='Erik Bernhardsson',
    author_email='erikbern@spotify.com',
    url='https://github.com/spotify/luigi',
    license='Apache License 2.0',
    packages=[
        'luigi',
        'luigi.contrib',
    ],
    package_data={
        'luigi': luigi_package_data
    },
    scripts=[
        'bin/luigid'
    ]
)
